@@ -1,7 +1,6 @@
 import socket
 import gymnasium as gym
 import math
-import numpy as np
 import pyglet
 from pyglet.window import key
 from FlagCapture.entity import MeshEnt
@@ -177,15 +176,14 @@ def forward(obj, speed):
         else:
             obj.pos = [x, 0, obj.pos[2]]
     else:
-        obj.pos = np.array([x, 0, z])
+        obj.pos = [x, 0, z]
     if carrying == 'red' and z < 0:blue_wins()
     if carrying == 'blue' and z > 0:red_wins()
 
 speed = 0.4
 
 def tell_pos_to_server(dt):
-    pos = [scene.agent.pos[0], scene.agent.pos[1], scene.agent.pos[2]]
-    cl.send(str(['Updating pos', {'pos': pos}]).encode('utf-8'))
+    cl.send(str(['Updating pos', {'pos': scene.agent.pos}]).encode('utf-8'))
 
 def tell_dir_to_server(dt):
     cl.send(str(['Updating dir', {'dir': scene.agent.dir}]).encode('utf-8'))
@@ -221,7 +219,9 @@ def update(dt):
         drop_flag()
 
     if board[key.SPACE]:
-        if scene.unwrapped.fuel > 2:
+        if scene.unwrapped.fuel < 3:
+            speed = 0.4
+        else:
             scene.unwrapped.fuel -= 3
             speed = 0.8
     else:
